# {{project.project_name}}
[![Documentation Status](https://readthedocs.org/projects/{{project.project_name}}/badge/?version=latest)](https://{{project.project_name}}.readthedocs.io/en/latest/?badge=latest)
[![Code coverage](https://codecov.io/github/{{project.owner}}/{{project.project_name}}/coverage.svg)](https://codecov.io/github/{{project.owner}}/{{project.project_name}})
[![PyPI package](https://badgen.net/pypi/v/{{project.project_name}})](https://pypi.org/project/{{project.project_name}}/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)
[![license: {{project.license}}](https://img.shields.io/badge/license-{{project.license}}-green.svg)](https://opensource.org/licenses/{{project.license}})

{{project.description}}